// --------------------------------------------------------------------------------------------------------------------
// <summary>
//    Defines the FirstViewModel type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

using System.Collections.Generic;
using System.Collections.ObjectModel;
using Chance.MvvmCross.Plugins.UserInteraction;
using Cirrious.CrossCore;
using Microsoft.AspNet.SignalR.Client;

namespace Chat5.Core.ViewModels
{
    using System.Windows.Input;
    using Cirrious.MvvmCross.ViewModels;

    /// <summary>
    /// Define the FirstViewModel type.
    /// </summary>
    public class FirstViewModel : BaseViewModel
    {
        /// <summary>
        /// Backing field for my property.
        /// </summary>
        private string myProperty = "Mvx Ninja Coder!";

        /// <summary>
        ///  Backing field for my command.
        /// </summary>
        private MvxCommand myCommand;

        private IHubProxy _chatHub;
        private MvxCommand _sendCommand;
        private HubConnection _hubConnection;
        private string _message;
        private string _name;



        public class MessageViewModel
        {
            public string Message { get; set; }
            public string Author { get; set; }
        }

        public ObservableCollection<MessageViewModel> Messages { get; set; }
        public ObservableCollection<MessageViewModel> MessagesWithNewestAtTheBottom { get; set; }

        public string Message
        {
            get { return _message; }
            set
            {
                _message = value;
                RaisePropertyChanged(() => Message);
                SendCommand.RaiseCanExecuteChanged();
            }
        }

        public MvxCommand SendCommand
        {
            get { return _sendCommand ?? (_sendCommand = new MvxCommand(Send, CanSend)); }
        }

        private void Send()
        {
            if ((_chatHub != null) && _hubConnection.State == ConnectionState.Connected)
            {
                _chatHub.Invoke("Send", new MessageViewModel()
                {
                    Message = Message,
                    Author = _name,
                });
                Message = "";
            }
        }

        private bool CanSend()
        {
            return !string.IsNullOrWhiteSpace(Message);
        }

        public async void Init()
        {

            Messages = new ObservableCollection<MessageViewModel>();
            MessagesWithNewestAtTheBottom = new ObservableCollection<MessageViewModel>();

            //_hubConnection = new HubConnection("http://demo08.rubius.com:15151/");

            //localhost won't work when run from Genymotion/iOS emulator/real devices
            _hubConnection = new HubConnection("http://localhost:5979");

            _chatHub = _hubConnection.CreateHubProxy("ChatHub");
            _chatHub.On<MessageViewModel>("NewMessage", MessageArrived);
            _hubConnection.Start();

            while (string.IsNullOrEmpty(_name))
            {
                var result = await Mvx.Resolve<IUserInteraction>().InputAsync("Your name", cancelButton: null);
                _name = result.Text;
            }

        }

        private void MessageArrived(MessageViewModel obj)
        {
            this.Dispatcher.RequestMainThreadAction(() =>
            {
                Messages.Insert(0, obj);
                MessagesWithNewestAtTheBottom.Add(obj);
            });

        }

        /// <summary>
        /// Gets or sets my property.
        /// </summary>
        public string MyProperty
        {
            get { return this.myProperty; }
            set { this.SetProperty(ref this.myProperty, value, () => this.MyProperty); }
        }

        /// <summary>
        /// Gets My Command.
        /// <para>
        /// An example of a command and how to navigate to another view model
        /// Note the ViewModel inside of ShowViewModel needs to change!
        /// </para>
        /// </summary>
        public ICommand MyCommand
        {
            get { return this.myCommand ?? (this.myCommand = new MvxCommand(this.Show)); }
        }

        /// <summary>
        /// Show the view model.
        /// </summary>
        public void Show()
        {
            this.ShowViewModel<FirstViewModel>();
        }
    }
}
